@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package CPAN::Uploader;
-our $VERSION = '0.093390';
+our $VERSION = '0.100660';
 # ABSTRACT: upload things to the CPAN
 
 
@@ -26,9 +26,9 @@ sub upload_file {
 
   $self = $self->new($arg) if $arg;
 
-  if($arg->{dry_run}) {
-    $self->_log("By request, cowardly refusing to do anything at all.");
-    $self->_log(
+  if ($arg->{dry_run}) {
+    $self->log("By request, cowardly refusing to do anything at all.");
+    $self->log(
       "The following arguments would have been used to upload: \n"
       . '$self: ' . Dumper($self)
       . '$file: ' . Dumper($file)
@@ -42,7 +42,7 @@ sub _upload {
   my $self = shift;
   my $file = shift;
 
-  $self->_log("registering upload with PAUSE web server");
+  $self->log("registering upload with PAUSE web server");
 
   my $agent = LWP::UserAgent->new;
   $agent->agent($self . q{/} . $self->VERSION);
@@ -65,14 +65,14 @@ sub _upload {
 
   $request->authorization_basic($self->{user}, $self->{password});
 
-  $self->_debug(
+  $self->log_debug(
     "----- REQUEST BEGIN -----" .
     $request->as_string .
     "----- REQUEST END -------"
   );
 
   # Make the request to the PAUSE web server
-  $self->_log("POSTing upload for $file");
+  $self->log("POSTing upload for $file");
   my $response = $agent->request($request);
 
   # So, how'd we do?
@@ -91,13 +91,13 @@ sub _upload {
         "\n  Message: ", $response->message, "\n";
     }
   } else {
-    $self->_debug(
+    $self->log_debug(
       "Looks OK!",
       "----- RESPONSE BEGIN -----",
       $response->as_string,
       "----- RESPONSE END -------"
     );
-    $self->_log("PAUSE add message sent ok [" . $response->code . "]");
+    $self->log("PAUSE add message sent ok [" . $response->code . "]");
   }
 }
 
@@ -110,15 +110,17 @@ sub new {
   bless $arg => $class;
 }
 
-sub _log {
+
+sub log {
   shift;
   print "$_[0]\n"
 }
 
-sub _debug {
+
+sub log_debug {
   my ($self) = @_;
   return unless $self->{debug};
-  $self->_log($_[0]);
+  $self->log($_[0]);
 }
 
 1;
@@ -132,7 +134,7 @@ CPAN::Uploader - upload things to the CPAN
 
 =head1 VERSION
 
-version 0.093390
+version 0.100660
 
 =head1 METHODS
 
@@ -162,6 +164,19 @@ this method.
 
 Valid arguments are the same as those to C<upload_file>.
 
+=head2 log
+
+  $uploader->log($message);
+
+This method logs the given string.  The default behavior is to print it to the
+screen.  The message should not end in a newline, as one will be added as
+needed.
+
+=head2 log_debug
+
+This method behaves like C<L</log>>, but only logs the message if the
+CPAN::Uploader is in debug mode.
+
 =head1 WARNING
 
   This is really, really not well tested or used yet.  Give it a few weeks, at
@@ -180,7 +195,7 @@ into this module.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2010 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
